@@ -22,4 +22,4 @@ REQUIRED_INTLTOOL_VERSION=0.40.4
 REQUIRED_AUTOMAKE_VERSION=1.9
 REQUIRED_GNOME_DOC_UTILS_VERSION=0.9.0
 NOCONFIGURE=yes . gnome-autogen.sh
-"${srcdir}/configure" --prefix=/usr --sysconfdir=/etc --mandir=/usr/share/man --disable-deprecations "$@"
+#"${srcdir}/configure" --prefix=/usr --sysconfdir=/etc --mandir=/usr/share/man --disable-deprecations "$@"
