@@ -182,10 +182,10 @@ on_group_changed (CFirstRecite_group * parent, gint zu_index,
 		parent->zu_words.m =
 			g_pReciteWord->now_book->words.m +
 			now_total_wordcount;
-		((GtkAdjustment *) g_pReciteWord->firstrecite_group->
-		 wordlist_adjust)->value = 0;
-		((GtkAdjustment *) g_pReciteWord->firstrecite_group->
-		 wordlist_adjust)->upper = now_zu_wordcount;
+		gtk_adjustment_set_value(g_pReciteWord->firstrecite_group->
+		 wordlist_adjust, 0);
+		gtk_adjustment_set_upper(g_pReciteWord->firstrecite_group->
+		 wordlist_adjust, now_zu_wordcount);
 		g_signal_emit_by_name (G_OBJECT
 				       (g_pReciteWord->firstrecite_group->
 					wordlist_adjust), "changed");
@@ -211,7 +211,7 @@ static void
 on_group_wordlistadjust_valuechanged (GtkAdjustment * adj,
 				      CFirstRecite_group * parent)
 {
-	int newvalue = ((gint) adj->value);
+	int newvalue = ((gint) gtk_adjustment_get_value(adj));
 
 	parent->set_wordlist_label (newvalue);
 }
@@ -278,56 +278,56 @@ CFirstRecite_group::~CFirstRecite_group ()
 void
 CFirstRecite_group::do_up ()
 {
-	int nowvalue = ((gint) ((GtkAdjustment *)wordlist_adjust)->value);
+	int nowvalue = ((gint) gtk_adjustment_get_value(wordlist_adjust));
 	if (nowvalue>0)
 	{
 		nowvalue--;
-		(((GtkAdjustment *) wordlist_adjust)->value = nowvalue);
+		gtk_adjustment_set_value(wordlist_adjust, nowvalue);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
-		on_group_wordlistadjust_valuechanged((GtkAdjustment *) wordlist_adjust,this);
+		on_group_wordlistadjust_valuechanged(wordlist_adjust,this);
 	}
 }
 
 void
 CFirstRecite_group::do_down ()
 {
-	int nowvalue = ((gint) ((GtkAdjustment *)wordlist_adjust)->value);
-	if (nowvalue < ((gint) (((GtkAdjustment *)wordlist_adjust)->upper - ((GtkAdjustment *)wordlist_adjust)->page_size)))
+	int nowvalue = ((gint) gtk_adjustment_get_value(wordlist_adjust));
+	if (nowvalue < ((gint) gtk_adjustment_get_upper(wordlist_adjust) - (gint)gtk_adjustment_get_page_size(wordlist_adjust)))
 	{
 		nowvalue++;
-		(((GtkAdjustment *) wordlist_adjust)->value = nowvalue);
+		gtk_adjustment_set_value(wordlist_adjust, nowvalue);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
-		on_group_wordlistadjust_valuechanged((GtkAdjustment *) wordlist_adjust,this);
+		on_group_wordlistadjust_valuechanged(wordlist_adjust,this);
 	}
 }
 
 void
 CFirstRecite_group::do_pageup ()
 {
-	int nowvalue = ((gint) ((GtkAdjustment *)wordlist_adjust)->value);
+	int nowvalue = ((gint) gtk_adjustment_get_value(wordlist_adjust));
 	if (nowvalue> 0)
 	{
-		nowvalue-= (gint) ((GtkAdjustment *)wordlist_adjust)->page_increment;
+		nowvalue-= (gint) gtk_adjustment_get_page_increment(wordlist_adjust);
 		if (nowvalue < 0)
 			nowvalue = 0;
-		(((GtkAdjustment *) wordlist_adjust)->value = nowvalue);
+		gtk_adjustment_set_value(wordlist_adjust, nowvalue);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
-		on_group_wordlistadjust_valuechanged((GtkAdjustment *) wordlist_adjust,this);
+		on_group_wordlistadjust_valuechanged(wordlist_adjust,this);
 	}
 }
 
 void
 CFirstRecite_group::do_pagedown ()
 {
-	int nowvalue = ((gint) ((GtkAdjustment *)wordlist_adjust)->value);
-	if (nowvalue < ((gint) (((GtkAdjustment *)wordlist_adjust)->upper - ((GtkAdjustment *)wordlist_adjust)->page_size)))
+	int nowvalue = ((gint) gtk_adjustment_get_value(wordlist_adjust));
+	if (nowvalue < ((gint) gtk_adjustment_get_upper(wordlist_adjust) - (gint)gtk_adjustment_get_page_size(wordlist_adjust)))
 	{
-		nowvalue+=(gint) ((GtkAdjustment *)wordlist_adjust)->page_increment;
-		if (nowvalue > ((gint) (((GtkAdjustment *)wordlist_adjust)->upper - ((GtkAdjustment *)wordlist_adjust)->page_size)))
-			nowvalue = ((gint) (((GtkAdjustment *)wordlist_adjust)->upper - ((GtkAdjustment *)wordlist_adjust)->page_size));
-		(((GtkAdjustment *) wordlist_adjust)->value = nowvalue);
+		nowvalue+=(gint) gtk_adjustment_get_page_increment(wordlist_adjust);
+		if (nowvalue > ((gint) (gtk_adjustment_get_upper(wordlist_adjust) - gtk_adjustment_get_page_size(wordlist_adjust))))
+			nowvalue = ((gint) (gtk_adjustment_get_upper(wordlist_adjust) - gtk_adjustment_get_page_size(wordlist_adjust)));
+		gtk_adjustment_set_value(wordlist_adjust, nowvalue);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
-		on_group_wordlistadjust_valuechanged((GtkAdjustment *) wordlist_adjust,this);
+		on_group_wordlistadjust_valuechanged(wordlist_adjust,this);
 	}
 }
 
@@ -339,18 +339,18 @@ CFirstRecite_group::do_scroll(GdkEventScroll * event)
 	if ((event->x_root>=x+Skin->group.wordlist_area.x[0])&&(event->x_root<=x+Skin->group.wordlist_area.x[0]+Skin->group.wordlist_area.w)
 		&&(event->y_root>=y+Skin->group.wordlist_area.y[0])&&(event->y_root<=y+Skin->group.wordlist_area.y[0]+Skin->group.wordlist_area.h))
 	{
-		GtkAdjustment *adj = (GtkAdjustment *)wordlist_adjust;
-		gdouble new_value = adj->value + ((event->direction == GDK_SCROLL_UP ||
+		GtkAdjustment *adj = wordlist_adjust;
+		gdouble new_value = gtk_adjustment_get_value(adj) + ((event->direction == GDK_SCROLL_UP ||
                                          event->direction == GDK_SCROLL_LEFT) ? 
-					-adj->page_increment / 2: 
-					adj->page_increment / 2);
-		if (new_value>(adj->upper - adj->page_size)) // warning,adj->upper may ==0,this time shouldn't be scrolled.
-			new_value = (adj->upper - adj->page_size);
+					-gtk_adjustment_get_page_increment(adj) / 2: 
+					gtk_adjustment_get_page_increment(adj) / 2);
+		if (new_value>(gtk_adjustment_get_upper(adj) - gtk_adjustment_get_page_size(adj))) // warning,adj->upper may ==0,this time shouldn't be scrolled.
+			new_value = (gtk_adjustment_get_upper(adj) - gtk_adjustment_get_page_size(adj));
 		if (new_value<0)
 			new_value=0;
-		if (new_value!=adj->value)
+		if (new_value!=gtk_adjustment_get_value(adj))
 		{
-			adj->value = new_value;
+			gtk_adjustment_set_value(adj, new_value);
 			g_signal_emit_by_name (wordlist_adjust, "changed");
 			on_group_wordlistadjust_valuechanged(adj,this);
 		}
@@ -409,7 +409,7 @@ CFirstRecite_group::show ()
 			      Skin->group.return_button.y[0],
 			      Skin->group.return_button.p[0],
 			      Skin->group.return_button.p[1],
-			      Skin->group.return_button.p[2], (GdkPixmap *) NULL,
+			      Skin->group.return_button.p[2], (GdkPixbuf *) NULL,
 			      on_group_return_clicked);
 	order_ckbutton.create (g_pReciteWord->fixed,
 			       Skin->group.order_ckbutton.x[0],
@@ -450,7 +450,11 @@ CFirstRecite_group::show ()
 	gtk_widget_show (book_wordcount_label);
 	GtkWidget *hbox;
 
+#if GTK_MAJOR_VERSION >= 3
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
+#else
 	hbox = gtk_hbox_new (FALSE, 10);
+#endif
 	wordlist_label_1_w = gtk_label_new ("");
 	gtk_label_set_selectable(GTK_LABEL(wordlist_label_1_w),true);
 	SetFont(wordlist_label_1_w,false);
@@ -471,7 +475,11 @@ CFirstRecite_group::show ()
 		       Skin->group.wordlist_label_1.y[0]);
 	gtk_widget_show (hbox);
 
+#if GTK_MAJOR_VERSION >= 3
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
+#else
 	hbox = gtk_hbox_new (FALSE, 10);
+#endif
 	wordlist_label_2_w = gtk_label_new ("");
 	gtk_label_set_selectable(GTK_LABEL(wordlist_label_2_w),true);
 	SetFont(wordlist_label_2_w,false);
@@ -492,7 +500,11 @@ CFirstRecite_group::show ()
 		       Skin->group.wordlist_label_2.y[0]);
 	gtk_widget_show (hbox);
 
+#if GTK_MAJOR_VERSION >= 3
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
+#else
 	hbox = gtk_hbox_new (FALSE, 10);
+#endif
 	wordlist_label_3_w = gtk_label_new ("");
 	gtk_label_set_selectable(GTK_LABEL(wordlist_label_3_w),true);
 	SetFont(wordlist_label_3_w,false);
@@ -513,7 +525,11 @@ CFirstRecite_group::show ()
 		       Skin->group.wordlist_label_3.y[0]);
 	gtk_widget_show (hbox);
 
+#if GTK_MAJOR_VERSION >= 3
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
+#else
 	hbox = gtk_hbox_new (FALSE, 10);
+#endif
 	wordlist_label_4_w = gtk_label_new ("");
 	gtk_label_set_selectable(GTK_LABEL(wordlist_label_4_w),true);
 	SetFont(wordlist_label_4_w,false);
@@ -534,7 +550,11 @@ CFirstRecite_group::show ()
 		       Skin->group.wordlist_label_4.y[0]);
 	gtk_widget_show (hbox);
 
+#if GTK_MAJOR_VERSION >= 3
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
+#else
 	hbox = gtk_hbox_new (FALSE, 10);
+#endif
 	wordlist_label_5_w = gtk_label_new ("");
 	gtk_label_set_selectable(GTK_LABEL(wordlist_label_5_w),true);
 	SetFont(wordlist_label_5_w,false);
@@ -566,12 +586,15 @@ CFirstRecite_group::show ()
 	g_signal_connect (G_OBJECT (zu_entry), "changed",
 			  G_CALLBACK (on_group_zuentry_changed), this);
 	gtk_widget_show (zu_entry);
-	wordlist_adjust = gtk_adjustment_new (0, 0, 0, 1, 5, 5);
+	wordlist_adjust = GTK_ADJUSTMENT(gtk_adjustment_new (0, 0, 0, 1, 5, 5));
 	g_signal_connect (G_OBJECT (wordlist_adjust), "value_changed",
 			  G_CALLBACK (on_group_wordlistadjust_valuechanged),
 			  this);
-	wordlist_vscroll =
-		gtk_vscrollbar_new ((GtkAdjustment *) wordlist_adjust);
+#if GTK_MAJOR_VERSION >= 3
+	wordlist_vscroll = gtk_scrollbar_new (GTK_ORIENTATION_VERTICAL, wordlist_adjust);
+#else
+	wordlist_vscroll = gtk_vscrollbar_new (wordlist_adjust);
+#endif
 	gtk_widget_set_size_request (wordlist_vscroll, Skin->group.wordlist_vscroll.w,
 			      Skin->group.wordlist_vscroll.h);
 	gtk_widget_show (wordlist_vscroll);
@@ -674,8 +697,8 @@ firstrecite_skim_select_next_word (gpointer data)
 	}
 	int nowvalue =
 		((gint)
-		 ((GtkAdjustment *) g_pReciteWord->firstrecite_skim->
-		  wordlist_adjust)->value);
+		 gtk_adjustment_get_value(g_pReciteWord->firstrecite_skim->
+		  wordlist_adjust));
 
 	g_pReciteWord->firstrecite_skim->selected_wordlist_item++;
 	//if (((g_pReciteWord->firstrecite_skim->selected_wordlist_item)>=nowvalue+6)||((g_pReciteWord->firstrecite_skim->selected_wordlist_item)<nowvalue))
@@ -687,8 +710,8 @@ firstrecite_skim_select_next_word (gpointer data)
 			selected_wordlist_item;
 		if (nowvalue > g_pReciteWord->now_zu_wordcount - 6)
 			nowvalue = g_pReciteWord->now_zu_wordcount - 6;
-		(((GtkAdjustment *) g_pReciteWord->firstrecite_skim->
-		  wordlist_adjust)->value = nowvalue);
+		gtk_adjustment_set_value(g_pReciteWord->firstrecite_skim->
+		  wordlist_adjust, nowvalue);
 		g_pReciteWord->firstrecite_skim->set_wordlist_item (nowvalue);
 		g_signal_emit_by_name (g_pReciteWord->firstrecite_skim->
 					 wordlist_adjust, "changed");
@@ -731,7 +754,7 @@ on_skim_start_clicked ()
 								     skim.
 								     start_button.
 								     p[2],
-								     (GdkPixmap
+								     (GdkPixbuf
 								      *)
 								     NULL);
 		g_pReciteWord->firstrecite_skim->started = false;
@@ -742,8 +765,8 @@ on_skim_start_clicked ()
 		{
 			g_pReciteWord->firstrecite_skim->dialog.close();
 		}
-		((GtkAdjustment *) g_pReciteWord->firstrecite_skim->
-		 wordlist_adjust)->value = 0;
+		gtk_adjustment_set_value(g_pReciteWord->firstrecite_skim->
+		 wordlist_adjust, 0);
 		g_signal_emit_by_name (g_pReciteWord->firstrecite_skim->
 					 wordlist_adjust, "changed");
 		g_pReciteWord->firstrecite_skim->selected_wordlist_item = 0;
@@ -797,7 +820,7 @@ on_skim_pause_clicked ()
 								     skim.
 								     continue_button.
 								     p[2],
-								     (GdkPixmap
+								     (GdkPixbuf
 								      *)
 								     NULL);
 		g_pReciteWord->firstrecite_skim->started = false;
@@ -889,7 +912,7 @@ static void
 on_skim_wordlistadjust_valuechanged (GtkAdjustment * adj,
 				     CFirstRecite_skim * parent)
 {
-	int newvalue = ((gint) adj->value);
+	int newvalue = ((gint) gtk_adjustment_get_value(adj));
 
 	if (((parent->selected_wordlist_item) >= newvalue)
 	    && ((parent->selected_wordlist_item) < (newvalue + 6)))
@@ -914,8 +937,8 @@ on_skim_wordlistitem_clicked (int index)
 
 	int i = index +
 		((gint)
-		 ((GtkAdjustment *) g_pReciteWord->firstrecite_skim->
-		  wordlist_adjust)->value);
+		 gtk_adjustment_get_value(g_pReciteWord->firstrecite_skim->
+		  wordlist_adjust));
 	g_pReciteWord->firstrecite_skim->selected_wordlist_item = i;
 	g_pReciteWord->firstrecite_skim->set_wordview_label (i);
 }
@@ -954,7 +977,7 @@ CFirstRecite_skim::show ()
 			     Skin->skim.stop_button.p[1],
 			     Skin->skim.stop_button.p[2],
 			     Skin->skim.stop_button.p[3], on_skim_start_clicked);
-	gtk_tooltips_set_tip (GTK_TOOLTIPS (g_pReciteWord->tooltips), start_button.event_box,"Ctrl-S","");
+	gtk_widget_set_tooltip_text(start_button.event_box,"Ctrl-S");
 	pause_button.create (g_pReciteWord->fixed, Skin->skim.pause_button.x[0],
 			     Skin->skim.pause_button.y[0],
 			     Skin->skim.pause_button.p[0],
@@ -962,25 +985,25 @@ CFirstRecite_skim::show ()
 			     Skin->skim.pause_button.p[2],
 			     Skin->skim.pause_button.p[3],
 			     on_skim_pause_clicked);
-	gtk_tooltips_set_tip (GTK_TOOLTIPS (g_pReciteWord->tooltips), pause_button.event_box,"Ctrl-P","");
+	gtk_widget_set_tooltip_text(pause_button.event_box,"Ctrl-P");
 	group_button.create (g_pReciteWord->fixed, Skin->skim.group_button.x[0],
 			     Skin->skim.group_button.y[0],
 			     Skin->skim.group_button.p[0],
 			     Skin->skim.group_button.p[1],
-			     Skin->skim.group_button.p[2], (GdkPixmap *) NULL,
+			     Skin->skim.group_button.p[2], (GdkPixbuf *) NULL,
 			     on_skim_group_clicked);
-	gtk_tooltips_set_tip (GTK_TOOLTIPS (g_pReciteWord->tooltips), group_button.event_box,"Ctrl-G","");
+	gtk_widget_set_tooltip_text(group_button.event_box,"Ctrl-G");
 	test_button.create (g_pReciteWord->fixed, Skin->skim.test_button.x[0],
 			    Skin->skim.test_button.y[0], Skin->skim.test_button.p[0],
 			    Skin->skim.test_button.p[1],
-			    Skin->skim.test_button.p[2], (GdkPixmap *) NULL,
+			    Skin->skim.test_button.p[2], (GdkPixbuf *) NULL,
 			    on_skim_test_clicked);
-	gtk_tooltips_set_tip (GTK_TOOLTIPS (g_pReciteWord->tooltips), test_button.event_box,"Ctrl-T","");
+	gtk_widget_set_tooltip_text(test_button.event_box,"Ctrl-T");
 	return_button.create (g_pReciteWord->fixed, Skin->skim.return_button.x[0],
 			      Skin->skim.return_button.y[0],
 			      Skin->skim.return_button.p[0],
 			      Skin->skim.return_button.p[1],
-			      Skin->skim.return_button.p[2], (GdkPixmap *) NULL,
+			      Skin->skim.return_button.p[2], (GdkPixbuf *) NULL,
 			      on_skim_return_clicked);
 	readword_ckbutton.create (g_pReciteWord->fixed, Skin->skim.readword_ckbutton.x[0],
 			      Skin->skim.readword_ckbutton.y[0],
@@ -1033,8 +1056,12 @@ CFirstRecite_skim::show ()
 			      Skin->skim.readword_button.p[1],
 			      Skin->skim.readword_button.p[2],
 				  on_skim_readword_button_clicked,this);
-	gtk_tooltips_set_tip (GTK_TOOLTIPS (g_pReciteWord->tooltips), readword_button.event_box,"Tab","");
+	gtk_widget_set_tooltip_text(readword_button.event_box,"Tab");
+#if GTK_MAJOR_VERSION >= 3
+	sentencelist_vscroll = gtk_scrollbar_new (GTK_ORIENTATION_VERTICAL, (GtkAdjustment *) NULL);
+#else
 	sentencelist_vscroll = gtk_vscrollbar_new ((GtkAdjustment *) NULL);
+#endif
 	gtk_widget_set_size_request (sentencelist_vscroll,
 			      Skin->skim.sentencelist_vscroll.w,
 			      Skin->skim.sentencelist_vscroll.h);
@@ -1126,14 +1153,17 @@ CFirstRecite_skim::show ()
 				 on_skim_wordlistitem_clicked, 5);
 
 	wordlist_adjust =
-		gtk_adjustment_new (0, 0, g_pReciteWord->now_zu_wordcount, 1,
-				    6, 6);
+		GTK_ADJUSTMENT(gtk_adjustment_new (0, 0, g_pReciteWord->now_zu_wordcount, 1,
+				    6, 6));
 	g_signal_connect (G_OBJECT (wordlist_adjust), "value_changed",
 			  G_CALLBACK (on_skim_wordlistadjust_valuechanged),
 			  this);
 
-	wordlist_vscroll =
-		gtk_vscrollbar_new ((GtkAdjustment *) wordlist_adjust);
+#if GTK_MAJOR_VERSION >= 3
+	wordlist_vscroll = gtk_scrollbar_new (GTK_ORIENTATION_VERTICAL, wordlist_adjust);
+#else
+	wordlist_vscroll =  gtk_vscrollbar_new (wordlist_adjust);
+#endif
 	gtk_widget_set_size_request (wordlist_vscroll, Skin->skim.wordlist_vscroll.w,
 			      Skin->skim.wordlist_vscroll.h);
 	gtk_widget_show (wordlist_vscroll);
@@ -1276,7 +1306,7 @@ CFirstRecite_skim::do_up ()
 		return;
 	int nowvalue =
 		((gint)
-		 ((GtkAdjustment *) wordlist_adjust)->value);
+		 gtk_adjustment_get_value(wordlist_adjust));
 
 	selected_wordlist_item--;
 	if (((selected_wordlist_item)>=nowvalue+6)||((selected_wordlist_item)<nowvalue))
@@ -1284,7 +1314,7 @@ CFirstRecite_skim::do_up ()
 		nowvalue = selected_wordlist_item;
 		if (nowvalue > g_pReciteWord->now_zu_wordcount - 6)
 			nowvalue = g_pReciteWord->now_zu_wordcount - 6;
-		(((GtkAdjustment *) wordlist_adjust)->value = nowvalue);
+		gtk_adjustment_set_value(wordlist_adjust, nowvalue);
 		set_wordlist_item (nowvalue);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
 	}
@@ -1307,7 +1337,7 @@ CFirstRecite_skim::do_down ()
 		return;
 	int nowvalue =
 		((gint)
-		 ((GtkAdjustment *) wordlist_adjust)->value);
+		 gtk_adjustment_get_value(wordlist_adjust));
 
 	selected_wordlist_item++;
 	if (((selected_wordlist_item)>=nowvalue+6)||((selected_wordlist_item)<nowvalue))
@@ -1316,7 +1346,7 @@ CFirstRecite_skim::do_down ()
 			nowvalue = 0;
 		else
 			nowvalue = selected_wordlist_item-5;
-		(((GtkAdjustment *) wordlist_adjust)->value = nowvalue);
+		gtk_adjustment_set_value(wordlist_adjust, nowvalue);
 		set_wordlist_item (nowvalue);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
 	}
@@ -1335,26 +1365,26 @@ CFirstRecite_skim::do_down ()
 void
 CFirstRecite_skim::do_left ()
 {
-	int nowvalue = ((gint) ((GtkAdjustment *)wordlist_adjust)->value);
+	int nowvalue = ((gint) gtk_adjustment_get_value(wordlist_adjust));
 	if (nowvalue>0)
 	{
 		nowvalue--;
-		(((GtkAdjustment *) wordlist_adjust)->value = nowvalue);
+		gtk_adjustment_set_value(wordlist_adjust, nowvalue);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
-		on_skim_wordlistadjust_valuechanged((GtkAdjustment *)wordlist_adjust,this);
+		on_skim_wordlistadjust_valuechanged(wordlist_adjust,this);
 	}
 }
 
 void
 CFirstRecite_skim::do_right ()
 {
-	int nowvalue = ((gint) ((GtkAdjustment *)wordlist_adjust)->value);
-	if (nowvalue < ((gint) (((GtkAdjustment *)wordlist_adjust)->upper - ((GtkAdjustment *)wordlist_adjust)->page_size)))
+	int nowvalue = ((gint) gtk_adjustment_get_value(wordlist_adjust));
+	if (nowvalue < ((gint) (gtk_adjustment_get_upper(wordlist_adjust) - gtk_adjustment_get_page_size(wordlist_adjust))))
 	{
 		nowvalue++;
-		(((GtkAdjustment *) wordlist_adjust)->value = nowvalue);
+		gtk_adjustment_set_value(wordlist_adjust, nowvalue);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
-		on_skim_wordlistadjust_valuechanged((GtkAdjustment *)wordlist_adjust,this);
+		on_skim_wordlistadjust_valuechanged(wordlist_adjust,this);
 	}
 }
 
@@ -1363,14 +1393,14 @@ CFirstRecite_skim::do_pageup ()
 {
 	int nowvalue =
 		((gint)
-		 ((GtkAdjustment *) wordlist_adjust)->value);
+		 gtk_adjustment_get_value(wordlist_adjust));
 
 	if (((selected_wordlist_item)>=nowvalue+6)||((selected_wordlist_item)<nowvalue))
 	{
 		nowvalue = selected_wordlist_item;
 		if (nowvalue > g_pReciteWord->now_zu_wordcount - 6)
 			nowvalue = g_pReciteWord->now_zu_wordcount - 6;
-		(((GtkAdjustment *) wordlist_adjust)->value = nowvalue);
+		gtk_adjustment_set_value(wordlist_adjust, nowvalue);
 		set_wordlist_item (nowvalue);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
 		wordlist_item[((selected_wordlist_item) -
@@ -1388,7 +1418,7 @@ CFirstRecite_skim::do_pageup ()
 	if (((selected_wordlist_item)>=nowvalue+6)||((selected_wordlist_item)<nowvalue))
 	{
 		nowvalue = selected_wordlist_item;
-		(((GtkAdjustment *) wordlist_adjust)->value = nowvalue);
+		gtk_adjustment_set_value(wordlist_adjust, nowvalue);
 		set_wordlist_item (nowvalue);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
 	}
@@ -1409,14 +1439,14 @@ CFirstRecite_skim::do_pagedown ()
 {
 	int nowvalue =
 		((gint)
-		 ((GtkAdjustment *) wordlist_adjust)->value);
+		 gtk_adjustment_get_value(wordlist_adjust));
 
 	if (((selected_wordlist_item)>=nowvalue+6)||((selected_wordlist_item)<nowvalue))
 	{
 		nowvalue = selected_wordlist_item;
 		if (nowvalue > g_pReciteWord->now_zu_wordcount - 6)
 			nowvalue = g_pReciteWord->now_zu_wordcount - 6;
-		(((GtkAdjustment *) wordlist_adjust)->value = nowvalue);
+		gtk_adjustment_set_value(wordlist_adjust, nowvalue);
 		set_wordlist_item (nowvalue);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
 		wordlist_item[((selected_wordlist_item) -
@@ -1434,7 +1464,7 @@ CFirstRecite_skim::do_pagedown ()
 	if (((selected_wordlist_item)>=nowvalue+6)||((selected_wordlist_item)<nowvalue))
 	{
 		nowvalue = selected_wordlist_item -5;
-		(((GtkAdjustment *) wordlist_adjust)->value = nowvalue);
+		gtk_adjustment_set_value(wordlist_adjust, nowvalue);
 		set_wordlist_item (nowvalue);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
 	}
@@ -1457,12 +1487,12 @@ CFirstRecite_skim::do_home ()
 		return;
 	int nowvalue =
 		((gint)
-		 ((GtkAdjustment *) wordlist_adjust)->value);
+		 gtk_adjustment_get_value(wordlist_adjust));
 
 	selected_wordlist_item = 0;
 	if (nowvalue!=0)
 	{
-		((GtkAdjustment *) wordlist_adjust)->value = 0;
+		gtk_adjustment_set_value(wordlist_adjust, 0);
 		set_wordlist_item (0);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
 	}
@@ -1484,12 +1514,12 @@ CFirstRecite_skim::do_end ()
 		return;
 	int nowvalue =
 		((gint)
-		 ((GtkAdjustment *) wordlist_adjust)->value);
+		 gtk_adjustment_get_value(wordlist_adjust));
 
 	selected_wordlist_item = g_pReciteWord->now_zu_wordcount-1;
 	if (nowvalue!=g_pReciteWord->now_zu_wordcount-6)
 	{
-		((GtkAdjustment *) wordlist_adjust)->value = g_pReciteWord->now_zu_wordcount-6;
+		gtk_adjustment_set_value(wordlist_adjust, g_pReciteWord->now_zu_wordcount-6);
 		set_wordlist_item (g_pReciteWord->now_zu_wordcount-6);
 		g_signal_emit_by_name (wordlist_adjust, "changed");
 	}
@@ -1521,18 +1551,18 @@ CFirstRecite_skim::do_scroll(GdkEventScroll * event)
 				&&(event->y_root>=dialog_y)&&(event->y_root<=dialog_y+Skin->skim.dialog.h))
 				return;
 		}
-		GtkAdjustment *adj = (GtkAdjustment *)wordlist_adjust;
-		gdouble new_value = adj->value + ((event->direction == GDK_SCROLL_UP ||
+		GtkAdjustment *adj = wordlist_adjust;
+		gdouble new_value = gtk_adjustment_get_value(adj) + ((event->direction == GDK_SCROLL_UP ||
                                          event->direction == GDK_SCROLL_LEFT) ? 
-					-adj->page_increment / 2: 
-					adj->page_increment / 2);
+					-gtk_adjustment_get_page_increment(adj) / 2: 
+					gtk_adjustment_get_page_increment(adj) / 2);
 		if (new_value<0)
 			new_value=0;
-		else if (new_value>(adj->upper-adj->page_size))
-			new_value = (adj->upper-adj->page_size);
-		if (new_value!=adj->value)
+		else if (new_value>(gtk_adjustment_get_upper(adj)-gtk_adjustment_get_page_size(adj)))
+			new_value = (gtk_adjustment_get_upper(adj)-gtk_adjustment_get_page_size(adj));
+		if (new_value!=gtk_adjustment_get_value(adj))
 		{
-			adj->value = new_value;
+			gtk_adjustment_set_value(adj, new_value);
 			g_signal_emit_by_name (wordlist_adjust, "changed");
 			on_skim_wordlistadjust_valuechanged (adj,this);
 		}
@@ -1579,7 +1609,7 @@ void
 CSkimDialog::show ()
 {
 	fixed = gtk_fixed_new ();
-	gtk_fixed_set_has_window(GTK_FIXED(fixed),TRUE);
+	gtk_widget_set_has_window(fixed,TRUE);
 	gtk_widget_set_size_request (fixed, Skin->skim.dialog.w,
 			      Skin->skim.dialog.h);
 	gtk_fixed_put (GTK_FIXED (g_pReciteWord->fixed), fixed,
@@ -1735,7 +1765,7 @@ tListItem::init ()
 
 void
 tListItem::create (GSList * group, GtkWidget * pfixed, gint x, gint y, gint w,
-		   gint h, GdkPixmap * pix_1, GdkPixmap * pix_2, void (*func) (int), int data)
+		   gint h, GdkPixbuf * pix_1, GdkPixbuf * pix_2, void (*func) (int), int data)
 {
 	init ();
 
@@ -1747,7 +1777,7 @@ tListItem::create (GSList * group, GtkWidget * pfixed, gint x, gint y, gint w,
 	fixed = gtk_fixed_new ();
 	gtk_widget_set_events (fixed, GDK_BUTTON_RELEASE_MASK | GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);
 	gtk_widget_set_size_request (fixed, w, h);
-	gtk_fixed_set_has_window(GTK_FIXED(fixed),TRUE);
+	gtk_widget_set_has_window(fixed,TRUE);
 //      gtk_widget_set_app_paintable(fixed,TRUE);
 	gtk_fixed_put (GTK_FIXED (pfixed), fixed, x, y);
 	label = gtk_label_new ("");
@@ -1766,7 +1796,7 @@ tListItem::create (GSList * group, GtkWidget * pfixed, gint x, gint y, gint w,
 			  G_CALLBACK(on_listitem_leave_notify), this);
 
 	SetBackPixmap (fixed, pix_normal);
-	gdk_window_set_cursor (fixed->window, Skin->reciteword.hand_cursor.cursor);
+	gdk_window_set_cursor (gtk_widget_get_window(fixed), Skin->reciteword.hand_cursor.cursor);
 
 	if (group)
 		set_group (group);
