@@ -8,7 +8,8 @@
 #include "skin.h"
 #include <glib/gi18n.h>
 
-#ifndef _WIN32
+#if defined(_WIN32) || defined(CONFIG_DARWIN)
+#else
 #include <espeak/speak_lib.h>
 #endif
 
@@ -998,6 +999,7 @@ static void on_test_tts_button_clicked(GtkWidget *widget, GtkEntry *entry)
 	g_pReciteWord->wyabdc.synth(word);
 }
 #endif
+#elif defined(CONFIG_DARWIN)
 #else
 static void on_setup_misc_tts_combobox_changed(GtkComboBox *widget, COption *parent)
 {
@@ -1124,6 +1126,7 @@ rw_preferences_dialog_setup_misc_tts_page(GtkNotebook *nb, COption *parent)
 	gtk_box_pack_start(GTK_BOX(hbox), button, false, false, 0);
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(on_test_tts_button_clicked), GTK_ENTRY(entry));
 #endif
+#elif defined(CONFIG_DARWIN)
 #else
 #if GTK_MAJOR_VERSION >= 3
 	GtkWidget *hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
