@@ -1,6 +1,6 @@
 /* ReciteWord - Recite Word Eassily
  * http://reciteword.sourceforge.net
- * Copyright (C) 2002-2012 Hu Zheng <huzheng001@gmail.com>
+ * Copyright (C) 2002-2013 Hu Zheng <huzheng001@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -1771,6 +1771,14 @@ static gboolean set_reciteword_data_dir(void) {
 	strcpy( (char*)&reciteword_data_dir, buf );
 	g_free( buf );
 	return false;
+#elif defined(CONFIG_DARWIN)
+	const gchar* dir = g_getenv("RECITEWORD_DATA_DIR");
+	if (dir) {
+		strcpy(reciteword_data_dir, dir);
+	} else {
+		strcpy(reciteword_data_dir, RECITEWORD_DATA_DIR);
+	}
+	return false;
 #else
 	strcpy(reciteword_data_dir, RECITEWORD_DATA_DIR);
 	return false;
@@ -1795,12 +1803,18 @@ int main(int argc, char *argv[])
 	locale_dir = g_strdup_printf("%s" G_DIR_SEPARATOR_S "locale", reciteword_data_dir);
 	bindtextdomain (GETTEXT_PACKAGE, locale_dir);
 	g_free(locale_dir);
+#elif defined(CONFIG_DARWIN)
+	const gchar* dir = g_getenv("RECITEWORD_LOCALE_DIR");
+	if (dir) {
+		bindtextdomain (GETTEXT_PACKAGE, dir);
+	} else {
+		bindtextdomain (GETTEXT_PACKAGE, RECITEWORD_LOCALEDIR);
+	}
 #else
 	bindtextdomain (GETTEXT_PACKAGE, RECITEWORD_LOCALEDIR);
 #endif	
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
-	g_thread_init(NULL);
 #ifdef G_OS_WIN32
 	gtk_init (&_argc, &_argv);
 
