@@ -1,7 +1,13 @@
 #ifndef __RECITEWORD_H__
 #define __RECITEWORD_H__
 
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <unistd.h>
+
 #include "bookfile.h"
 #include "widget.h"
 #include "help.h"
