@@ -5,6 +5,7 @@
 
 #ifdef G_OS_WIN32
     #include "windows.h"
+#elif defined(CONFIG_DARWIN)
 #else
 	#include <esd.h>
 #endif
@@ -26,7 +27,9 @@ CSndserv::~CSndserv()
 
 void CSndserv::end()
 {
-#ifndef G_OS_WIN32
+#ifdef G_OS_WIN32
+#elif defined(CONFIG_DARWIN)
+#else
 	if (fd>=0) {
 		esd_close(fd);
 		fd = -1;
@@ -38,6 +41,13 @@ void CSndserv::init()
 {
 #ifdef G_OS_WIN32
 	canplay = true;
+#elif defined(CONFIG_DARWIN)
+	if (always_use_sound_play_command) {
+		canplay = true;
+	} else {
+		// Need future work...
+		canplay = false;
+	}
 #else
 	if (always_use_sound_play_command) {
 		canplay = true;
@@ -62,6 +72,7 @@ void
 CSndserv::play(const gchar *filename)
 {
 #ifdef G_OS_WIN32
+#elif defined(CONFIG_DARWIN)
 #else
 	if (fd>=0)
 		esd_play_file(NULL,filename,0); // ???
@@ -132,11 +143,14 @@ void play_file(const char *filename,PLAY_METHOD method)
 				gchar *efilename = g_shell_quote(filename);
 				gchar *command = g_strdup_printf("%s %s &", g_pReciteWord->sndserv.playcmd.c_str(), efilename);
 				g_free(efilename);
-				system(command);
+				int result = system(command);
+				if (result == -1) {
+					g_print("run command error!\n");
+				}
 				g_free(command);
 			} else {
 				gchar *dup_filename = g_strdup(filename); //as in the new thread, filename may have already be freeed.
-				g_thread_create(play_file_mix,(gpointer)dup_filename,false,NULL);  //use GThreadPool may be more efficient.
+				g_thread_unref(g_thread_new("play_file_mix", play_file_mix, (gpointer)dup_filename));  //use GThreadPool may be more efficient.
 			}
 #endif
 			break;
