@@ -18,8 +18,8 @@ on_pixbutton_button_press (GtkWidget * widget, GdkEvent * event,
 	playsound (SND_BUTTONDOWN);
 	if (parent->pix_down)  // in shooting form,there are 4 button without pix_down.
 	{
-		gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-				parent->pix_down, (GdkBitmap *) NULL);
+		gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+				parent->pix_down);
 	}
 	return TRUE;
 }
@@ -35,8 +35,8 @@ on_pixbutton_button_release (GtkWidget * widget, GdkEvent * event,
 
 	if (parent->pix_down)
 	{
-		gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-				parent->pix_normal, (GdkBitmap *) NULL);
+		gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+				parent->pix_normal);
 	}
 	if (parent->mousein)
 	{
@@ -88,8 +88,8 @@ tPixButton::init ()
 }
 
 void
-tPixButton::create (GtkWidget * fixed, gint x, gint y, GdkPixmap * pix_1,
-		    GdkPixmap * pix_2, GdkPixmap * pix_3,
+tPixButton::create (GtkWidget * fixed, gint x, gint y, GdkPixbuf * pix_1,
+		    GdkPixbuf * pix_2, GdkPixbuf * pix_3,
 		    void (*func) (gpointer), gpointer funcdata0)
 {
 	init ();
@@ -102,7 +102,7 @@ tPixButton::create (GtkWidget * fixed, gint x, gint y, GdkPixmap * pix_1,
 
 	event_box = gtk_event_box_new ();
 	gtk_fixed_put (GTK_FIXED (fixed), event_box, x, y);
-	pixmap_widget = gtk_image_new_from_pixmap (pix_normal, (GdkBitmap *) NULL);
+	pixmap_widget = gtk_image_new_from_pixbuf (pix_normal);
 	gtk_container_add (GTK_CONTAINER (event_box), pixmap_widget);
 	g_signal_connect (G_OBJECT (event_box), "button_press_event",
 			  G_CALLBACK (on_pixbutton_button_press), this);
@@ -114,7 +114,7 @@ tPixButton::create (GtkWidget * fixed, gint x, gint y, GdkPixmap * pix_1,
 			  G_CALLBACK (on_pixbutton_leave_notify), this);
 
 	gtk_widget_realize (event_box);
-	gdk_window_set_cursor (event_box->window, Skin->reciteword.hand_cursor.cursor);
+	gdk_window_set_cursor (gtk_widget_get_window(event_box), Skin->reciteword.hand_cursor.cursor);
 	gtk_widget_show_all (event_box);
 }
 
@@ -125,17 +125,15 @@ tPixButton::set_enable (int a)
 	{
 		if (a)
 		{
-			gdk_window_set_cursor (event_box->window, Skin->reciteword.hand_cursor.cursor);
-			gtk_image_set_from_pixmap (GTK_IMAGE (pixmap_widget),
-					pix_normal, (GdkBitmap *) NULL);
+			gdk_window_set_cursor (gtk_widget_get_window(event_box), Skin->reciteword.hand_cursor.cursor);
+			gtk_image_set_from_pixbuf (GTK_IMAGE (pixmap_widget),
+					pix_normal);
 		}
 		else
 		{
-			gdk_window_set_cursor (event_box->window, Skin->reciteword.disable_cursor.cursor);
+			gdk_window_set_cursor (gtk_widget_get_window(event_box), Skin->reciteword.disable_cursor.cursor);
 			if (pix_disable)
-				gtk_image_set_from_pixmap (GTK_IMAGE (pixmap_widget),
-						pix_disable,
-						(GdkBitmap *) NULL);
+				gtk_image_set_from_pixbuf (GTK_IMAGE (pixmap_widget), pix_disable);
 		}
 		enable = a;
 	}
@@ -156,13 +154,13 @@ on_checkbutton_button_press (GtkWidget * widget, GdkEvent * event,
 	playsound (SND_BUTTONDOWN);
 	if (parent->status)
 	{
-		gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-				parent->pix_t_down, (GdkBitmap *) NULL);
+		gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+				parent->pix_t_down);
 	}
 	else
 	{
-		gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-				parent->pix_f_down, (GdkBitmap *) NULL);
+		gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+				parent->pix_f_down);
 	}
 	return TRUE;
 }
@@ -184,13 +182,13 @@ on_checkbutton_button_release (GtkWidget * widget, GdkEvent * event,
 	{
 		if (parent->status)
 		{
-			gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-					parent->pix_t_normal, (GdkBitmap *) NULL);
+			gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+					parent->pix_t_normal);
 		}
 		else
 		{
-			gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-					parent->pix_f_normal, (GdkBitmap *) NULL);
+			gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+					parent->pix_f_normal);
 		}
 	}
 	return TRUE;
@@ -228,8 +226,8 @@ tCheckButton::init ()
 }
 
 void
-tCheckButton::create (GtkWidget * fixed, gint x, gint y, GdkPixmap * pix_1,
-		      GdkPixmap * pix_2, GdkPixmap * pix_3, GdkPixmap * pix_4,
+tCheckButton::create (GtkWidget * fixed, gint x, gint y, GdkPixbuf * pix_1,
+		      GdkPixbuf * pix_2, GdkPixbuf * pix_3, GdkPixbuf * pix_4,
 		      void (*func) ())
 {
 	init ();
@@ -243,7 +241,7 @@ tCheckButton::create (GtkWidget * fixed, gint x, gint y, GdkPixmap * pix_1,
 
 	event_box = gtk_event_box_new ();
 	gtk_fixed_put (GTK_FIXED (fixed), event_box, x, y);
-	pixmap_widget = gtk_image_new_from_pixmap (pix_t_normal, (GdkBitmap *) NULL);
+	pixmap_widget = gtk_image_new_from_pixbuf (pix_t_normal);
 	gtk_container_add (GTK_CONTAINER (event_box), pixmap_widget);
 	g_signal_connect (G_OBJECT (event_box), "button_press_event",
 			  G_CALLBACK (on_checkbutton_button_press), this);
@@ -255,7 +253,7 @@ tCheckButton::create (GtkWidget * fixed, gint x, gint y, GdkPixmap * pix_1,
 			  G_CALLBACK (on_checkbutton_leave_notify), this);
 
 	gtk_widget_realize (event_box);
-	gdk_window_set_cursor (event_box->window, Skin->reciteword.hand_cursor.cursor);
+	gdk_window_set_cursor (gtk_widget_get_window(event_box), Skin->reciteword.hand_cursor.cursor);
 	gtk_widget_show_all (event_box);
 
 }
@@ -273,11 +271,11 @@ tCheckButton::set_enable (gboolean e)
 	{
 		if (e)
 		{
-			gdk_window_set_cursor (event_box->window, Skin->reciteword.hand_cursor.cursor);
+			gdk_window_set_cursor (gtk_widget_get_window(event_box), Skin->reciteword.hand_cursor.cursor);
 		}
 		else
 		{
-			gdk_window_set_cursor (event_box->window, Skin->reciteword.disable_cursor.cursor);
+			gdk_window_set_cursor (gtk_widget_get_window(event_box), Skin->reciteword.disable_cursor.cursor);
 		}
 		enable = e;
 	}
@@ -290,11 +288,11 @@ tCheckButton::set_status (int newstatus)
 	{
 		status = newstatus;
 		if (newstatus)
-			gtk_image_set_from_pixmap (GTK_IMAGE (pixmap_widget),
-					pix_t_normal, (GdkBitmap *) NULL);
+			gtk_image_set_from_pixbuf (GTK_IMAGE (pixmap_widget),
+					pix_t_normal);
 		else
-			gtk_image_set_from_pixmap (GTK_IMAGE (pixmap_widget),
-					pix_f_normal, (GdkBitmap *) NULL);
+			gtk_image_set_from_pixbuf (GTK_IMAGE (pixmap_widget),
+					pix_f_normal);
 	}
 }
 
@@ -307,8 +305,7 @@ on_pixbutton2_button_press (GtkWidget * widget, GdkEvent * event,
 
 	parent->pressed=true;
 	playsound (SND_BUTTONDOWN);
-	gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget), parent->pix_down,
-			(GdkBitmap *) NULL);
+	gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget), parent->pix_down);
 	return TRUE;
 }
 
@@ -322,16 +319,14 @@ on_pixbutton2_button_release (GtkWidget * widget, GdkEvent * event,
 	playsound (SND_BUTTONUP);
 	if (parent->mousein)
 	{
-		gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-				parent->pix_active,
-				(GdkBitmap *) NULL);
+		gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+				parent->pix_active);
 		(*(parent->runfunc)) ();
 	}
 	else
 	{
-		gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-				parent->pix_normal,
-				(GdkBitmap *) NULL);
+		gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+				parent->pix_normal);
 	}
 	return TRUE;
 }
@@ -349,8 +344,8 @@ on_pixbutton2_enter_notify (GtkWidget * widget, GdkEventCrossing * event,
 	if (!parent->pressed)
 	{
 		playsound (SND_BUTTONACTIVE);
-		gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-				parent->pix_active, (GdkBitmap *) NULL);
+		gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+				parent->pix_active);
 	}
 	return true;
 }
@@ -367,8 +362,8 @@ on_pixbutton2_leave_notify (GtkWidget * widget, GdkEventCrossing * event,
 		return true;
 	if (!parent->pressed)
 	{
-		gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-				parent->pix_normal, (GdkBitmap *) NULL);
+		gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+				parent->pix_normal);
 	}
 	return true;
 }
@@ -399,8 +394,8 @@ tPixButton2::init ()
 }
 
 void
-tPixButton2::create (GtkWidget * fixed, gint x, gint y, GdkPixmap * pix_1,
-		     GdkPixmap * pix_2, GdkPixmap * pix_3, GdkPixmap * pix_4,
+tPixButton2::create (GtkWidget * fixed, gint x, gint y, GdkPixbuf * pix_1,
+		     GdkPixbuf * pix_2, GdkPixbuf * pix_3, GdkPixbuf * pix_4,
 		     void (*func) ())
 {
 	pix_normal = pix_1;
@@ -416,7 +411,7 @@ tPixButton2::create (GtkWidget * fixed, gint x, gint y, GdkPixmap * pix_1,
 	gtk_widget_show (event_box);
 
 
-	pixmap_widget = gtk_image_new_from_pixmap (pix_normal, (GdkBitmap *) NULL);
+	pixmap_widget = gtk_image_new_from_pixbuf (pix_normal);
 	gtk_container_add (GTK_CONTAINER (event_box), pixmap_widget);
 	gtk_widget_show (pixmap_widget);
 
@@ -429,12 +424,12 @@ tPixButton2::create (GtkWidget * fixed, gint x, gint y, GdkPixmap * pix_1,
 	g_signal_connect (G_OBJECT (event_box), "leave_notify_event",
 			  G_CALLBACK (on_pixbutton2_leave_notify), this);
 
-	gdk_window_set_cursor (event_box->window, Skin->reciteword.hand_cursor.cursor);
+	gdk_window_set_cursor (gtk_widget_get_window(event_box), Skin->reciteword.hand_cursor.cursor);
 }
 
 void
-tPixButton2::reset (GdkPixmap * pix_1, GdkPixmap * pix_2, GdkPixmap * pix_3,
-		    GdkPixmap * pix_4)
+tPixButton2::reset (GdkPixbuf * pix_1, GdkPixbuf * pix_2, GdkPixbuf * pix_3,
+		    GdkPixbuf * pix_4)
 {
 	if ((pix_normal == pix_1) && (pix_active == pix_2)
 	    && (pix_down == pix_3) && (pix_disable == pix_4))
@@ -447,11 +442,9 @@ tPixButton2::reset (GdkPixmap * pix_1, GdkPixmap * pix_2, GdkPixmap * pix_3,
 
 
 	if (mousein)
-		gtk_image_set_from_pixmap (GTK_IMAGE (pixmap_widget), pix_active,
-				(GdkBitmap *) NULL);
+		gtk_image_set_from_pixbuf (GTK_IMAGE (pixmap_widget), pix_active);
 	else
-		gtk_image_set_from_pixmap (GTK_IMAGE (pixmap_widget), pix_normal,
-				(GdkBitmap *) NULL);
+		gtk_image_set_from_pixbuf (GTK_IMAGE (pixmap_widget), pix_normal);
 }
 
 void
@@ -461,22 +454,20 @@ tPixButton2::set_enable (int a)
 	{
 		if (a)
 		{
-			gdk_window_set_cursor (event_box->window, Skin->reciteword.hand_cursor.cursor);
+			gdk_window_set_cursor (gtk_widget_get_window(event_box), Skin->reciteword.hand_cursor.cursor);
 			if (mousein)
-				gtk_image_set_from_pixmap (GTK_IMAGE (pixmap_widget),
-						pix_active,
-						(GdkBitmap *) NULL);
+				gtk_image_set_from_pixbuf (GTK_IMAGE (pixmap_widget),
+						pix_active);
 			else
-				gtk_image_set_from_pixmap (GTK_IMAGE (pixmap_widget),
-						pix_normal,
-						(GdkBitmap *) NULL);
+				gtk_image_set_from_pixbuf (GTK_IMAGE (pixmap_widget),
+						pix_normal);
 		}
 		else
 		{
-			gdk_window_set_cursor (event_box->window, Skin->reciteword.disable_cursor.cursor);
+			gdk_window_set_cursor (gtk_widget_get_window(event_box), Skin->reciteword.disable_cursor.cursor);
 			if (pix_disable)
-				gtk_image_set_from_pixmap (GTK_IMAGE (pixmap_widget),
-					pix_disable, (GdkBitmap *) NULL);
+				gtk_image_set_from_pixbuf (GTK_IMAGE (pixmap_widget),
+					pix_disable);
 		}
 		enable = a;
 	}
@@ -497,14 +488,14 @@ on_radiobutton_button_press (GtkWidget * widget, GdkEvent * event,
 	if (parent->selected)
 	{
 		if (parent->pix_t_down)
-			gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-					parent->pix_t_down, (GdkBitmap *) NULL);
+			gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+					parent->pix_t_down);
 	}
 	else
 	{
 		if (parent->pix_f_down)
-			gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-					parent->pix_f_down, (GdkBitmap *) NULL);
+			gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+					parent->pix_f_down);
 	}
 	return TRUE;
 }
@@ -516,8 +507,8 @@ on_radiobutton_button_release (GtkWidget * widget, GdkEvent * event,
 	playsound (SND_BUTTONUP);
 	if (parent->selected)
 	{
-		gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-				parent->pix_t_normal, (GdkBitmap *) NULL);
+		gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+				parent->pix_t_normal);
 	}
 	else
 	{
@@ -529,8 +520,8 @@ on_radiobutton_button_release (GtkWidget * widget, GdkEvent * event,
 		}
 		else
 		{
-			gtk_image_set_from_pixmap (GTK_IMAGE (parent->pixmap_widget),
-					parent->pix_f_normal, (GdkBitmap *) NULL);
+			gtk_image_set_from_pixbuf (GTK_IMAGE (parent->pixmap_widget),
+					parent->pix_f_normal);
 		}
 	}
 	return TRUE;
@@ -569,8 +560,8 @@ tRadioButton::init ()
 
 void
 tRadioButton::create (GSList * group, GtkWidget * fixed, gint x, gint y,
-		      GdkPixmap * pix_1, GdkPixmap * pix_2, GdkPixmap * pix_3,
-		      GdkPixmap * pix_4, void (*func) (const gpointer), const gpointer funcdata1)
+		      GdkPixbuf * pix_1, GdkPixbuf * pix_2, GdkPixbuf * pix_3,
+		      GdkPixbuf * pix_4, void (*func) (const gpointer), const gpointer funcdata1)
 {
 	init ();
 
@@ -584,7 +575,7 @@ tRadioButton::create (GSList * group, GtkWidget * fixed, gint x, gint y,
 
 	event_box = gtk_event_box_new ();
 	gtk_fixed_put (GTK_FIXED (fixed), event_box, x, y);
-	pixmap_widget = gtk_image_new_from_pixmap (pix_f_normal, (GdkBitmap *) NULL);
+	pixmap_widget = gtk_image_new_from_pixbuf (pix_f_normal);
 	gtk_container_add (GTK_CONTAINER (event_box), pixmap_widget);
 	g_signal_connect (G_OBJECT (event_box), "button_press_event",
 			  G_CALLBACK (on_radiobutton_button_press), this);
@@ -597,7 +588,7 @@ tRadioButton::create (GSList * group, GtkWidget * fixed, gint x, gint y,
 			  G_CALLBACK(on_radiobutton_leave_notify), this);
 
 	gtk_widget_realize (event_box);
-	gdk_window_set_cursor (event_box->window, Skin->reciteword.hand_cursor.cursor);
+	gdk_window_set_cursor (gtk_widget_get_window(event_box), Skin->reciteword.hand_cursor.cursor);
 	gtk_widget_show_all (event_box);
 
 	if (group)
@@ -661,12 +652,12 @@ tRadioButton::set_selected (int a)
 					break;
 				}
 			}
-			gtk_image_set_from_pixmap (GTK_IMAGE (pixmap_widget),
-					pix_t_normal, (GdkBitmap *) NULL);
+			gtk_image_set_from_pixbuf (GTK_IMAGE (pixmap_widget),
+					pix_t_normal);
 		}
 		else
-			gtk_image_set_from_pixmap (GTK_IMAGE (pixmap_widget),
-					pix_f_normal, (GdkBitmap *) NULL);
+			gtk_image_set_from_pixbuf (GTK_IMAGE (pixmap_widget),
+					pix_f_normal);
 		this->selected = a;
 	}
 }
@@ -700,18 +691,26 @@ tRadioButton::destroy ()
 	gtk_widget_destroy (event_box);
 }
 
-
+#if GTK_MAJOR_VERSION >= 3
+static gboolean
+on_entry_draw (GtkWidget * widget, cairo_t *cr, tEntry * parent)
+{
+	cairo_set_source_surface(cr, parent->draw_surface, 0, 0);
+	cairo_paint(cr);
+	return TRUE;
+}
+#else
 static gint
 on_entry_expose (GtkWidget * widget, GdkEventExpose * event, tEntry * parent)
 {
-	gdk_draw_drawable (widget->window,
-			 widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
-			 parent->draw_pixmap,
-			 event->area.x, event->area.y,
-			 event->area.x, event->area.y,
-			 event->area.width, event->area.height);
+	cairo_t *cr;
+	cr = gdk_cairo_create (widget->window);
+	cairo_set_source_surface(cr, parent->draw_surface, 0, 0);
+	cairo_paint(cr);
+	cairo_destroy (cr);
 	return FALSE;
 }
+#endif
 
 static gint
 on_entry_timer_active (gpointer data)
@@ -737,7 +736,7 @@ on_entry_buttonpress (GtkWidget * widget, GdkEventButton * event,
 {
 	if (event->type == GDK_BUTTON_PRESS)
 	{
-		if (!GTK_WIDGET_HAS_FOCUS (widget))
+		if (!gtk_widget_has_focus (widget))
 			gtk_widget_grab_focus (widget);
 	}
 	return true;
@@ -769,7 +768,7 @@ on_entry_keypress (GtkWidget * widget, GdkEventKey * event, tEntry * parent)
 
 	switch (event->keyval)
 	{
-	case GDK_BackSpace:
+	case GDK_KEY_BackSpace:
 		return_val = TRUE;
 		if (position == 0)
 			return TRUE;
@@ -783,36 +782,36 @@ on_entry_keypress (GtkWidget * widget, GdkEventKey * event, tEntry * parent)
 			position--;
 		}
 		break;
-	case GDK_Delete:
+	case GDK_KEY_Delete:
 		return_val = TRUE;
 		if (position == length)
 			return TRUE;
 		text0[position] = '\0';
 		sprintf (text, "%s%s", text0, text0 + position + 1);
 		break;
-	case GDK_Home:
+	case GDK_KEY_Home:
 		return_val = TRUE;
 		position = 0;
 		break;
-	case GDK_End:
+	case GDK_KEY_End:
 		return_val = TRUE;
 		position = length;
 		break;
-	case GDK_Left:
+	case GDK_KEY_Left:
 		return_val = TRUE;
 		if (position != 0)
 			position--;
 		break;
-	case GDK_Right:
+	case GDK_KEY_Right:
 		return_val = TRUE;
 		if (position != length)
 			position++;
 		break;
-	case GDK_Return:
+	case GDK_KEY_Return:
 		return TRUE;
 		break;
-	case GDK_Tab:
-	case GDK_Escape:
+	case GDK_KEY_Tab:
+	case GDK_KEY_Escape:
 		break;
 	default:
 		return_val = TRUE;
@@ -851,23 +850,11 @@ tEntry::init ()
 	max_length = 40;
 	position = 0;
 	timer = 0;
-	gc1 = gdk_gc_new (g_pReciteWord->window->window);
-	gc2 = gdk_gc_new (g_pReciteWord->window->window);
-	GdkColormap *cmap = gdk_rgb_get_colormap ();
-	GdkColor color1 = { 0, 48896, 48896, 48896 }, color2 =
-	{
-	0, 0xFFFF, 0x8000, 0x8000};
-	gdk_colormap_alloc_color (cmap, &(color1), FALSE, TRUE);
-	gdk_colormap_alloc_color (cmap, &(color2), FALSE, TRUE);
-	gdk_gc_set_foreground (gc1, &color1);
-	gdk_gc_set_foreground (gc2, &color2);
-	gdk_colormap_free_colors (cmap, &color1, 1);
-	gdk_colormap_free_colors (cmap, &color2, 1);
 }
 
 void
 tEntry::create (GtkWidget * pfixed, gint x, gint y, gint w,
-		gint h, gchar * str, gchar * right_text, gint show_pen0,
+		gint h, const gchar * str, const gchar * right_text, gint show_pen0,
 		gint (*func) (gint, gint))
 {
 	init ();
@@ -881,11 +868,16 @@ tEntry::create (GtkWidget * pfixed, gint x, gint y, gint w,
 	text_area = gtk_drawing_area_new ();
 	SetFont(text_area,true);
 	gtk_widget_set_size_request (text_area, width, height);
-	GTK_WIDGET_SET_FLAGS (text_area, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus(text_area, true);
 
 	gtk_widget_set_events (text_area, GDK_BUTTON_PRESS_MASK);
+#if GTK_MAJOR_VERSION >= 3
+	g_signal_connect (G_OBJECT (text_area), "draw",
+			  G_CALLBACK(on_entry_draw), this);
+#else
 	g_signal_connect (G_OBJECT (text_area), "expose_event",
 			  G_CALLBACK(on_entry_expose), this);
+#endif
 	g_signal_connect (G_OBJECT (text_area), "key_press_event",
 			  G_CALLBACK(on_entry_keypress), this);
 	g_signal_connect (G_OBJECT (text_area),
@@ -908,9 +900,7 @@ tEntry::create (GtkWidget * pfixed, gint x, gint y, gint w,
 		underline_w = 0;
 	}
 
-	draw_pixmap =
-		gdk_pixmap_new (text_area->window, width, height,
-				gdk_rgb_get_visual ()->depth);
+	draw_surface = gdk_window_create_similar_surface(gtk_widget_get_window(text_area), CAIRO_CONTENT_COLOR, width, height);
 	draw ();
 	timer = g_timeout_add (500, on_entry_timer_active, this);
 
@@ -920,31 +910,28 @@ tEntry::create (GtkWidget * pfixed, gint x, gint y, gint w,
 void
 tEntry::draw ()
 {
-	gdk_draw_rectangle (draw_pixmap, text_area->style->white_gc,
-			    TRUE, 0, 0, width, height);
+	cairo_t *cr = cairo_create (draw_surface);
+	cairo_set_source_rgb(cr, 1, 1, 1);
+	cairo_rectangle(cr, 0, 0, width, height);
+	cairo_fill (cr);
 	if (strcmp(pango_layout_get_text(layout),text)!=0)
 		pango_layout_set_text(layout,text,-1);
-	gdk_draw_layout(draw_pixmap,text_area->style->black_gc,Skin->text.entry_text.x[0],Skin->text.entry_text.y[0],layout);
-	/*gdk_draw_string (draw_pixmap, Skin->text.font,
-			 text_area->style->black_gc, Skin->text.entry_text.x[0],
-			 Skin->text.entry_text.y[0], text);*/
-	if (show_length)
-		gdk_draw_rectangle (draw_pixmap, gc1,
-				    TRUE, Skin->text.entry_underline.x[0],
-				    Skin->text.entry_underline.y[0], underline_w,
-				    Skin->text.entry_underline.h);
+	cairo_move_to(cr, Skin->text.entry_text.x[0],Skin->text.entry_text.y[0]);
+	cairo_set_source_rgb(cr, 0, 0, 0);
+	pango_cairo_show_layout(cr, layout);
+	if (show_length) {
+		cairo_set_source_rgb(cr, 48896/(double)0xFFFF, 48896/(double)0xFFFF, 48896/(double)0xFFFF);
+		cairo_rectangle (cr, Skin->text.entry_underline.x[0], Skin->text.entry_underline.y[0], underline_w, Skin->text.entry_underline.h);
+		cairo_fill(cr);
+	}
 	if (show_pen)
 	{
 		gint w;
 		pango_layout_get_pixel_size(layout,&w,NULL);
-		gdk_draw_drawable (draw_pixmap, text_area->style->white_gc,
-				 Skin->text.entry_pen.p[0], 0, 0,
-				 w /*gdk_string_width (Skin->text.font,
-						   text)*/ +
-				 Skin->text.entry_pen.x[0], Skin->text.entry_pen.y[0],
-				 Skin->text.entry_pen.w,
-				 Skin->text.entry_pen.h);
+		gdk_cairo_set_source_pixbuf(cr, Skin->text.entry_pen.p[0], w + Skin->text.entry_pen.x[0], Skin->text.entry_pen.y[0]);
+		cairo_paint (cr);
 	}
+	cairo_destroy (cr);
 	gtk_widget_queue_draw (text_area);
 }
 
@@ -958,24 +945,23 @@ tEntry::draw_cursor (gint a)
 	pango_layout_set_text(layout,text,position);
 	pango_layout_get_pixel_size(layout,&w,NULL);
 
+	cairo_t *cr = cairo_create (draw_surface);
 	if (a)
 	{
-		gdk_draw_rectangle (draw_pixmap, text_area->style->black_gc,
-				    TRUE, w /*gdk_text_width (Skin->text.font,
-							  text, position)*/,
-				    Skin->text.entry_cursor.y[0],
+		cairo_set_source_rgb(cr, 0, 0, 0);
+		cairo_rectangle (cr, w, Skin->text.entry_cursor.y[0],
 				    Skin->text.entry_cursor.w,
 				    Skin->text.entry_cursor.h);
-
+		cairo_fill(cr);
 	}
 	else
 	{
-		gdk_draw_rectangle (draw_pixmap, text_area->style->white_gc,
-				    TRUE, w /*gdk_text_width (Skin->text.font,
-							  text, position)*/,
+		cairo_set_source_rgb(cr, 1, 1, 1);
+		cairo_rectangle (cr, w,
 				    Skin->text.entry_cursor.y[0],
 				    Skin->text.entry_cursor.w,
 				    Skin->text.entry_cursor.h);
+		cairo_fill(cr);
 	/*if (position > 0)
 		{
 			gdk_draw_text (draw_pixmap, Skin->text.font,
@@ -997,23 +983,35 @@ tEntry::draw_cursor (gint a)
 				       text + position, 1);
 		}*/		
 		pango_layout_set_text(layout,text,-1);
-		gdk_draw_layout(draw_pixmap,text_area->style->black_gc,Skin->text.entry_text.x[0],Skin->text.entry_text.y[0],layout);
+		cairo_move_to(cr, Skin->text.entry_text.x[0],Skin->text.entry_text.y[0]);
+		cairo_set_source_rgb(cr, 0, 0, 0);
+		pango_cairo_show_layout(cr, layout);
 	}
+	cairo_destroy (cr);
 	gtk_widget_queue_draw (text_area);
 }
 
+static inline void my_cairo_stroke_rectangle_with_linewidth1(cairo_t *cr, int x, int y, int width, int height)
+{
+	cairo_rectangle(cr, x+0.5, y+0.5, width-1, height-1);
+	cairo_set_line_width(cr, 1);
+	cairo_stroke(cr);
+}
+
 void
 tEntry::check_text (gchar * str,SOUND_EVENTS right_snd_event,SOUND_EVENTS wrong_snd_event)
 {
 	show_cursor = FALSE;
 
+	cairo_t *cr = cairo_create (draw_surface);
 	if (strcmp (g_strstrip (text), str))
 	{
 		if (enablesnd)
 			playsound(wrong_snd_event);
 		gint w1,w2,w3;
-		gdk_draw_rectangle (draw_pixmap, text_area->style->white_gc,
-				    TRUE, 0, 0, width, height);
+		cairo_set_source_rgb(cr, 1, 1, 1);
+		cairo_rectangle (cr, 0, 0, width, height);
+		cairo_fill(cr);
 
 		int i, j, k;
 		j = strlen (str);
@@ -1028,19 +1026,8 @@ tEntry::check_text (gchar * str,SOUND_EVENTS right_snd_event,SOUND_EVENTS wrong_
 					pango_layout_get_pixel_size(layout,&w1,NULL);
 					pango_layout_set_text(layout,text+i,1);
 					pango_layout_get_pixel_size(layout,&w2,NULL);
-					gdk_draw_rectangle (draw_pixmap, gc2,
-							    FALSE,
-							     w1 /*gdk_text_width
-							    (Skin->text.font,
-							     text, i)*/,
-							    Skin->text.
-							    entry_cursor.y[0],
-							    w2 /*gdk_char_width
-							    (Skin->text.font,
-							     text[i])*/,
-							    Skin->text.
-							    entry_cursor.h -
-							    1);
+					cairo_set_source_rgb(cr, 1, 0x8000/(double)0xFFFF, 0x8000/(double)0xFFFF);
+					my_cairo_stroke_rectangle_with_linewidth1(cr, w1, Skin->text.entry_cursor.y[0], w2+1, Skin->text.entry_cursor.h -1);
 				}
 			}
 			for (i = k; i < j; i++)
@@ -1051,23 +1038,8 @@ tEntry::check_text (gchar * str,SOUND_EVENTS right_snd_event,SOUND_EVENTS wrong_
 				pango_layout_get_pixel_size(layout,&w2,NULL);				
 				pango_layout_set_text(layout,str+i,1);
 				pango_layout_get_pixel_size(layout,&w3,NULL);
-				gdk_draw_rectangle (draw_pixmap, gc2,
-						    FALSE,
-						    w1+w2 /*gdk_string_width (Skin->
-								      text.
-								      font,
-								      text) +
-						    gdk_text_width (Skin->text.
-								    font,
-								    str + k,
-								    i - k)*/,
-						    Skin->text.entry_cursor.y[0],
-						    w3 /*gdk_char_width (Skin->text.
-								    font,
-								    *(str +
-								      i))*/,
-						    Skin->text.entry_cursor.h -
-						    1);
+				cairo_set_source_rgb(cr, 1, 0x8000/(double)0xFFFF, 0x8000/(double)0xFFFF);
+				my_cairo_stroke_rectangle_with_linewidth1(cr, w1+w2, Skin->text.entry_cursor.y[0], w3+1, Skin->text.entry_cursor.h - 1);
 			}
 		}
 		else
@@ -1080,74 +1052,43 @@ tEntry::check_text (gchar * str,SOUND_EVENTS right_snd_event,SOUND_EVENTS wrong_
 					pango_layout_get_pixel_size(layout,&w1,NULL);
 					pango_layout_set_text(layout,text+i,1);
 					pango_layout_get_pixel_size(layout,&w2,NULL);
-					gdk_draw_rectangle (draw_pixmap, gc2,
-							    FALSE,
-							    w1 /*gdk_text_width
-							    (Skin->text.font,
-							     text, i)*/,
-							    Skin->text.
-							    entry_cursor.y[0],
-							    w2 /*gdk_char_width
-							    (Skin->text.font,
-							     text[i])*/,
-							    Skin->text.
-							    entry_cursor.h -
-							    1);
+					cairo_set_source_rgb(cr, 1, 0x8000/(double)0xFFFF, 0x8000/(double)0xFFFF);
+					my_cairo_stroke_rectangle_with_linewidth1(cr, w1, Skin->text.entry_cursor.y[0], w2+1, Skin->text.entry_cursor.h - 1);
 				}
 			}
 			pango_layout_set_text(layout,text,j);
 			pango_layout_get_pixel_size(layout,&w1,NULL);
 			pango_layout_set_text(layout,text+j,-1);
 			pango_layout_get_pixel_size(layout,&w2,NULL);
-			gdk_draw_rectangle (draw_pixmap, gc2,
-					    FALSE,
-					    w1 /*gdk_text_width (Skin->text.font,
-							    text, j)*/,
-					    Skin->text.entry_cursor.y[0],
-					    w2 /*gdk_string_width (Skin->text.font,
-							      text + j)*/,
-					    Skin->text.entry_cursor.h - 1);
+			cairo_set_source_rgb(cr, 1, 0x8000/(double)0xFFFF, 0x8000/(double)0xFFFF);
+			my_cairo_stroke_rectangle_with_linewidth1(cr, w1, Skin->text.entry_cursor.y[0], w2+1, Skin->text.entry_cursor.h - 1);
 		}
 		pango_layout_set_text(layout,text,-1);
-		gdk_draw_layout(draw_pixmap,text_area->style->black_gc,Skin->text.entry_text.x[0],Skin->text.entry_text.y[0],layout);
-		/*gdk_draw_string (draw_pixmap, Skin->text.font,
-				 text_area->style->black_gc,
-				 Skin->text.entry_text.x[0],
-				 Skin->text.entry_text.y[0], text);*/
+		cairo_move_to(cr, Skin->text.entry_text.x[0],Skin->text.entry_text.y[0]);
+		cairo_set_source_rgb(cr, 0, 0, 0);
+		pango_cairo_show_layout(cr, layout);
 		pango_layout_get_pixel_size(layout,&w1,NULL);
-		gdk_draw_drawable (draw_pixmap, text_area->style->white_gc,
-				 Skin->text.entry_wrong.p[0], 0, 0,
-				 w1 /*gdk_string_width (Skin->text.font,
-						   text)*/ +
-				 Skin->text.entry_wrong.x[0],
-				 Skin->text.entry_wrong.y[0],
-				 Skin->text.entry_wrong.w,
-				 Skin->text.entry_wrong.h);
+		gdk_cairo_set_source_pixbuf(cr, Skin->text.entry_wrong.p[0], w1 + Skin->text.entry_wrong.x[0], Skin->text.entry_wrong.y[0]);
+		cairo_paint(cr);
 	}
 	else
 	{
 		if (enablesnd)
 			playsound(right_snd_event);
-		gdk_draw_rectangle (draw_pixmap, text_area->style->white_gc,
-					TRUE, 0, 0, width, height);
+		cairo_set_source_rgb(cr, 1, 1, 1);
+		cairo_rectangle (cr, 0, 0, width, height);
+		cairo_fill(cr);
 		if (strcmp(pango_layout_get_text(layout),text)!=0)
 			pango_layout_set_text(layout,text,-1);
-		gdk_draw_layout(draw_pixmap,text_area->style->black_gc,Skin->text.entry_text.x[0],Skin->text.entry_text.y[0],layout);
-		/*gdk_draw_string (draw_pixmap, Skin->text.font,
-				 text_area->style->black_gc,
-				 Skin->text.entry_text.x[0],
-				 Skin->text.entry_text.y[0], text);*/
+		cairo_move_to(cr, Skin->text.entry_text.x[0],Skin->text.entry_text.y[0]);
+		cairo_set_source_rgb(cr, 0, 0, 0);
+		pango_cairo_show_layout(cr, layout);
 		gint w;
 		pango_layout_get_pixel_size(layout,&w,NULL);
-		gdk_draw_drawable (draw_pixmap, text_area->style->white_gc,
-				 Skin->text.entry_right.p[0], 0, 0,
-				 w /*gdk_string_width (Skin->text.font,
-						   text)*/ +
-				 Skin->text.entry_right.x[0],
-				 Skin->text.entry_right.y[0],
-				 Skin->text.entry_right.w,
-				 Skin->text.entry_right.h);
+		gdk_cairo_set_source_pixbuf(cr, Skin->text.entry_right.p[0], w + Skin->text.entry_right.x[0], Skin->text.entry_right.y[0]);
+		cairo_paint(cr);
 	}
+	cairo_destroy (cr);
 	gtk_widget_queue_draw (text_area);
 }
 
@@ -1190,7 +1131,7 @@ tEntry::changed (gchar * str, guint pos, gint keyval)
 }
 
 void
-tEntry::set_text (gchar * str)
+tEntry::set_text (const gchar * str)
 {
 	strcpy (text, str);
 	//pango_layout_set_text(layout,str,-1);
@@ -1211,16 +1152,20 @@ tEntry::set_showlength (gint a)
 {
 	if (a == show_length)
 		return;
-	if (a)
-		gdk_draw_rectangle (draw_pixmap, gc1,
-				    TRUE, Skin->text.entry_underline.x[0],
+	cairo_t *cr = cairo_create (draw_surface);
+	if (a) {
+		cairo_set_source_rgb(cr, 48896/(double)0xFFFF, 48896/(double)0xFFFF, 48896/(double)0xFFFF);
+		cairo_rectangle (cr, Skin->text.entry_underline.x[0],
 				    Skin->text.entry_underline.y[0], underline_w,
 				    Skin->text.entry_underline.h);
-	else
-		gdk_draw_rectangle (draw_pixmap, text_area->style->white_gc,
-				    TRUE, Skin->text.entry_underline.x[0],
+	} else {
+		cairo_set_source_rgb(cr, 1, 1, 1);
+		cairo_rectangle (cr, Skin->text.entry_underline.x[0],
 				    Skin->text.entry_underline.y[0], underline_w,
 				    Skin->text.entry_underline.h);
+	}
+	cairo_fill(cr);
+	cairo_destroy (cr);
 	gtk_widget_queue_draw (text_area);
 	show_length = a;
 }
@@ -1265,11 +1210,8 @@ tEntry::destroy ()
 	g_source_remove (timer);
 	if (layout)
 		g_object_unref (G_OBJECT (layout));
+	cairo_surface_destroy(draw_surface);
 	gtk_widget_destroy (text_area);
-	//gdk_gc_unref (gc1);
-	//gdk_gc_unref (gc2);
-	g_object_unref (G_OBJECT (gc1));
-	g_object_unref (G_OBJECT (gc2));
 }
 
 /*
@@ -1283,7 +1225,7 @@ tPhoneticLabel::~tPhoneticLabel ()
 
 
 static gboolean
-on_phoneticlabel_expose (GtkWidget * widget, GdkEventExpose * event,
+on_phoneticlabel_draw (GtkWidget * widget, cairo_t *cr,
 			 tPhoneticLabel * parent)
 {
 	gdk_draw_drawable (widget->window,
@@ -1309,8 +1251,8 @@ tPhoneticLabel::create (GtkWidget * pfixed, gint x, gint y, gint w, gint h,
 
 	text_area = gtk_drawing_area_new ();
 	gtk_widget_set_size_request (text_area, width, height);
-	g_signal_connect (G_OBJECT (text_area), "expose_event",
-			  G_CALLBACK (on_phoneticlabel_expose), this);
+	g_signal_connect (G_OBJECT (text_area), "draw",
+			  G_CALLBACK (on_phoneticlabel_draw), this);
 	gtk_fixed_put (GTK_FIXED (pfixed), text_area, x, y);
 	gtk_widget_show (text_area);
 	draw_pixmap =
@@ -1513,7 +1455,11 @@ CPhoneticLabel::create (GtkWidget * pfixed, gint x, gint y, struct _Skin_phoneti
 	text[0] = '\0';
 	ptc = phonetic;
 
-	hbox = gtk_hbox_new (false,0);
+#if GTK_MAJOR_VERSION >= 3
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
+	hbox = gtk_hbox_new (false, 0);
+#endif
 	gtk_fixed_put (GTK_FIXED (pfixed), hbox, x, y);
 	gtk_widget_show (hbox);
 }
